# sphinx

## Windows

To build the static HTML pages call ```make.bat html```, which generates them to ```./build/html```.

## Linux

To build the static HTML pages call ```make html```, which generates them to ```./build/html```.
